#Contains all Gateways

class Gateways:
    Global = 'https://gw.cmtelecom.com/v1.0/message'    #Global Endpoint URL
    CN = 'https://gw-cn.cmtelecom.com/v1.0/message'     #China Mainland Endpoint URL
    UK = 'https://gw-uk.cmtelecom.com/v1.0/message'     #London Endpoint URL
    ZA = 'https://gw.cmtelecom.co.za/v1.0/message'      #South Africa Endpoint URL
    HK = 'https://gw-hk.cmtelecom.com/v1.0/message'     #Hongkong Endpoint URL