
class TextClientStatusCodes:
    OK = 0
    AUTHENTICATION_FAILED = 101
    BALANCE_INSUFFICIENT = 102
    APIKEY_INCORRECT = 103
    REQUEST_NOT_ALL_SENT = 201
    REQUEST_MALFORMED = 202
    MSG_ARRAY_INCORRECT = 203
    MSG_INVALID_FROM = 301
    MSG_INVALID_TO = 302
    MSG_INVALID_MSISDN = 303
    MSG_INVALID_BODY = 304
    MSG_INVALID_FIELD = 305
    SPAM = 401
    BLACKLISTED = 402
    REJECTED = 403
    INTERNAL_ERROR = 500
    UNKNOWN = 999